//
//  ContentView.swift
//  Games
//
//  Created by Ben Albright on 10/17/23.
//

import SwiftUI

struct ContentView: View {
    
    @State var postContent: String = ""
    @State var duration: String = ""
    @State var numPlayer: String = ""
    @State private var timePicked = ""
    @State private var playersPicked = ""
    @State private var rating = "0"

    
    var body: some View {
        VStack {
            //HStack{
            //    Text("Cancel")
            //      .font(.title3)
            //      .foregroundColor(.red)
            //
            //  Spacer()
            //
            //  Text("Post")
            //      .font(.title3)
            //      .foregroundColor(.black)
            //      .fontWeight(.bold)
            //}
            //.padding(.horizontal)
            
            Text("New Post")
                .font(.title)
                .fontWeight(.bold)
            
            VStack{
                Text("Game")
                    .padding(.horizontal)
                    .hAlign(.leading)
                    .font(.title2)
                    .fontWeight(.bold)
                HStack{
                    Image("betrayal")
                        .resizable()
                        .scaledToFit()
                        .frame(width: 80, height: 80)
                    
                    VStack {
                        HStack {
                            Text("Betrayal at House on the Hill")
                                .fontWeight(.bold)
                                .font(.title3)
                            Spacer()
                        }
                        HStack {
                            Text("2-5 Players")
                            Text("60 Min")
                            Spacer()
                        }
                        HStack{
                            Text("Avalon Hill")
                            Text("2004")
                            Spacer()
                        }
                    }
                }
                .border(1, .gray.opacity(0.5))
            }
            
            VStack(spacing: 12){
                Text("Overal Rating")
                    .padding(.horizontal)
                    .hAlign(.leading)
                    .font(.title2)
                    .fontWeight(.bold)
                
                HStack {
                    Picker("Overall Rating",
                           selection: $rating) {
                        Text("0 Stars")
                            .tag("0")
                        //Text("0.5 Stars")
                            //.tag("0.5 Stars")
                        Text("1 Star")
                            .tag("1")
                        //Text("1.5 Stars")
                            //.tag("1.5 Stars")
                        Text("2 Stars")
                            .tag("2")
                        //Text("2.5 Stars")
                            //.tag("2.5 Stars")
                        Text("3 Stars")
                            .tag("3")
                        //Text("3.5 Stars")
                            //.tag("3.5 Stars")
                        Text("4 Stars")
                            .tag("4")
                        //Text("4.5 Stars")
                            //.tag("4.5 Stars")
                        Text("5 Stars")
                            .tag("5")
                    }
                           .padding(.horizontal)
                    
                    Spacer()
                    
                    Image("star\(rating)")
                        .resizable()
                        .scaledToFit()
                        //.frame(width: 150)
                        .padding(.horizontal)
                        
                }
                
                //TextField("Enter number here", text: $numPlayer)
                    //.textContentType(.emailAddress)
                    //.border(1, .gray.opacity(0.5))
                    //.keyboardType(.numberPad)
            }
            
            VStack(spacing: 12){
                Text("Number of Players")
                    .padding(.horizontal)
                    .hAlign(.leading)
                    .font(.title2)
                    .fontWeight(.bold)
                
                HStack {
                    Picker("Game Duration",
                           selection: $playersPicked) {
                        Text("1")
                            .tag("1")
                        Text("2")
                            .tag("2")
                        Text("3")
                            .tag("3")
                        Text("4")
                            .tag("4")
                        Text("5")
                            .tag("5")
                        Text("6")
                            .tag("6")
                        Text("7")
                            .tag("7")
                        Text("8")
                            .tag("8")
                        Text("9")
                            .tag("9")
                        Text("10+")
                            .tag("10+")
                    }
                       .padding(.horizontal)
                    
                    Spacer()
                }

                
                //TextField("Enter number here", text: $numPlayer)
                    //.textContentType(.emailAddress)
                    //.border(1, .gray.opacity(0.5))
                    //.keyboardType(.numberPad)
            }

            
            VStack(spacing: 12){
                Text("Estimated Play Time")
                    .padding(.horizontal)
                    .hAlign(.leading)
                    .font(.title2)
                    .fontWeight(.bold)
                
                HStack {
                    Picker("Game Duration",
                           selection: $timePicked) {
                        Text("15 Minutes")
                            .tag("15 Minutes")
                        Text("30 Minutes")
                            .tag("30 Minutes")
                        Text("45 Minutes")
                            .tag("45 Minutes")
                        Text("1 Hour")
                            .tag("1 Hour")
                        Text("1 Hour 15 Minutes")
                            .tag("1 Hour 15 Minutes")
                        Text("1 Hour 30 Minutes")
                            .tag("1 Hour 30 Minutes")
                        Text("1 Hour 45 Minutes")
                            .tag("1 Hour 45 Minutes")
                        Text("2 Hours")
                            .tag("2 Hours")
                        Text("2 Hours 15 Minutes")
                            .tag("2 Hours 15 Minutes")
                        Text("2 Hours 30 Minutes")
                            .tag("2 Hours 30 Minutes")
                        Text("2 Hours 45 Minutes")
                            .tag("2 Hours 45 Minutes")
                        Text("3+ Hours")
                            .tag("3+ Hours")
                        
                    }
                       .padding(.horizontal)
                    
                    Spacer()
                }

            }
            
            
            VStack(spacing: 12){
                Text("Your Review")
                    .padding(.horizontal)
                    .hAlign(.leading)
                    .font(.title2)
                    .fontWeight(.bold)
                
                TextField("Type your thoughts here", text: $postContent)
                    .textContentType(.emailAddress)
                    .padding(.horizontal,15)
                    .padding(.top,10)
                    .padding(.bottom,100)
                    .background {
                        RoundedRectangle(cornerRadius: 5, style: .continuous)
                            .stroke(.gray.opacity(0.5), lineWidth: 1)
                    }
                    .padding(.horizontal)
                
                Button("Post") {
                    
                }
                .padding()
                .background(Color("nd-purple"))
                .clipShape(Capsule())
                .padding(.bottom,30)
                .foregroundColor(.white)
                .font(.title)
                .fontWeight(.bold)
                .padding(.top)
            }
        }
        .vAlign(.top)
    }
}

#Preview {
    ContentView()
}

extension View{
    func disableWithOpacity(_ condition: Bool)->some View{
        self
            .disabled(condition)
            .opacity(condition ? 0.6 : 1)
    }
    
    
    func hAlign(_ alignment: Alignment)->some View{
        self
            .frame(maxWidth: .infinity, alignment: alignment)
    }
    
    func vAlign(_ alignment: Alignment)->some View{
        self
            .frame(maxHeight: .infinity, alignment: alignment)
    }
    
    func border(_ width: CGFloat,_ color: Color)->some View{
        self
            .padding(.horizontal,15)
            .padding(.vertical,10)
            .background {
                RoundedRectangle(cornerRadius: 5, style: .continuous)
                    .stroke(color, lineWidth: width)
            }
            .padding(.horizontal)
    }
    
    func fillView(_ color: Color)->some View{
        self
            .padding(.horizontal,15)
            .padding(.vertical,10)
            .background {
                RoundedRectangle(cornerRadius: 5, style: .continuous)
                    .fill(color)
            }
    }
}
